@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://github.com/Henryhaoson/sentry-dingtalk"
-    version = "2.0.2"
+    version = "2.0.3"
     resource_links = [
         ("Report Issue", "https://github.com/Henryhaoson/sentry-dingtalk/issues"),
         ("View Source", "https://github.com/Henryhaoson/sentry-dingtalk"),
@@ -79,15 +79,14 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
 
     def notify(self, notification, raise_exception=False):
         event = notification.event
-        user = event.get_minimal_user
+        user = event.get_minimal_user()
         user_id = user.id
-        environment = event.get_environment
         release = event.release
         group = event.group
         project = group.project
-        self._post(group, user_id, environment, release, project)
+        self._post(group, user_id, release, project)
 
-    def _post(self, group, userId, environment, release, project):
+    def _post(self, group, userId, release, project):
         webhook = self.get_option("webhook", project)
         ats_str = self.get_option("ats", project)
         ats_array = ats_str.split(",")
@@ -97,7 +96,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"## Error: [{group.title}]({issue_link}) \n\n"
         payload = f"{payload} #### UserId: [{userId}](https://admin.shanbay.com/jetty/users/{userId}) \n\n"
         payload = f"{payload} #### Project: {project.name} \n\n"
-        payload = f"{payload} #### release: {release}   environment: {environment} \n\n"
+        payload = f"{payload} #### release: {release} \n\n"
         payload = f"{payload} > Detail: {group.message} \n\n"
 
         headers = {
